@@ -478,4 +478,25 @@ REST_FRAMEWORK = {
 # Your stuff...
 # ------------------------------------------------------------------------------
 
+# django-project-backup
+SERIALIZATION_MODULES = {
+    'couchdb_datastore': 'django_project_backup.utils.couchdb.serializers'
+}
+
+DJANGO_PROJECT_BACKUP_EXCLUDED_MODELS = env.list('DJANGO_PROJECT_BACKUP_EXCLUDED_MODELS', default=[
+    'sessions',
+    'admin',
+    'auth.permission',
+    'contenttypes',
+    'django_sso_app.passepartout',
+    'django_sso_app.device'
+])
+
+COUCHDB_DATASTORE_DATABASE_NAME = env('COUCHDB_DATASTORE_DATABASE_NAME', default='django_sso_app')
+
+# django_couchdb_datastore settings
+COUCHDB_DATASTORE_HOST = env('COUCHDB_DATASTORE_HOST', default='http://127.0.0.1:5984')
+COUCHDB_DATASTORE_USER = env('COUCHDB_DATASTORE_USER', default='admin')
+COUCHDB_DATASTORE_PASSWORD = env('COUCHDB_DATASTORE_PASSWORD', default='couchdb')
+
 from .extra import *  # pai
