@@ -145,6 +145,25 @@ def create_apigw_consumer_acl(profile, group_name=app_settings.APIGATEWAY_CONSUM
     return status_code, response_body
 
 
+def get_apigw_consumer_acls(profile):
+    consumer_id = get_apigateway_consumer_id(profile.sso_id)
+    logger.info('getting apigw consumer groups for {}'.format(profile))
+
+    url = app_settings.APIGATEWAY_HOST + "/consumers/" + consumer_id + "/acls/"
+
+    r = requests.get(url)
+
+    response_body = None
+    status_code = r.status_code
+    try:
+        response_body = r.json()
+    except:
+        logger.info('Response ({}) has no payload'.format(status_code))
+
+    logger.info('apigw response ({0}) {1}'.format(status_code, response_body))
+    return status_code, response_body
+
+
 def delete_apigw_consumer_acl(profile, group_name):
     consumer_id = get_apigateway_consumer_id(profile.sso_id)
     logger.info('deleting apigw consumer acl {} for {}'.format(group_name,
