@@ -17,6 +17,6 @@ class DeviceSerializer(AbsoluteUrlSerializer):
 
     def get_profile(self, instance):
         request = self.context['request']
-        profile_url = instance.profile.get_absolute_url()
+        profile_url = instance.profile.get_absolute_rest_url()
 
         return request.build_absolute_uri(profile_url)
