@@ -50,6 +50,7 @@ class AbstractProfileModel(CreatedAtModel, UpdatableModel, DeactivableModel, Pub
                                   blank=True)
     last_name = models.CharField(_('last name'), max_length=255, null=True,
                                  blank=True)
+    alias = models.CharField(_('alias'), max_length=255, null=True, blank=True)
 
     # role = models.SmallIntegerField(null=True, blank=True)
 
@@ -69,6 +70,10 @@ class AbstractProfileModel(CreatedAtModel, UpdatableModel, DeactivableModel, Pub
 
     unsubscribed_at = models.DateTimeField(_('unsubscription date'), null=True, blank=True)
 
+    completed_at = models.DateTimeField(_('profile completion date'), null=True, blank=True)
+
+    meta = models.TextField(_('meta'), null=True, blank=True)
+
     @property
     def is_unsubscribed(self):
         return self.unsubscribed_at is not None
@@ -97,12 +102,24 @@ class AbstractProfileModel(CreatedAtModel, UpdatableModel, DeactivableModel, Pub
 
     @property
     def is_incomplete(self):
-        if app_settings.LOGIN_MUST_FILL_PROFILE:
-            for field in app_settings.REQUIRED_PROFILE_FIELDS:
-                if getattr(self, field, None) in [None, '']:
-                    return True
+        is_incomplete = False
 
-        return False
+        for field in app_settings.REQUIRED_PROFILE_FIELDS:
+            if getattr(self, field, None) in [None, '']:
+                is_incomplete = True
+
+        return is_incomplete
+
+    @property
+    def must_subscribe(self):
+        if app_settings.SERVICE_SUBSCRIPTION_REQUIRED:
+            user_service_subscription = self.subscriptions.filter(service__service_url=app_settings.SERVICE_URL,
+                                                                  is_unsubscribed=False).first()
+
+            if user_service_subscription is None:
+                return True
+
+        return self.is_unsubscribed
 
 
 class Profile(AbstractProfileModel):
@@ -114,6 +131,7 @@ class Profile(AbstractProfileModel):
                                 null=True, blank=True,
                                 verbose_name=_("user"),
                                 related_name="sso_app_profile")
+
     apigw_consumer_id = models.CharField(_('API gateway consumer id'), max_length=36, null=True, blank=True)
 
     groups = models.ManyToManyField(Group, blank=True, related_name='sso_app_profiles', verbose_name=_('groups'),
