@@ -19,6 +19,9 @@ def check_upated_fields(sender, instance, created, **kwargs):
     else:
         subscription = instance
         if subscription.is_unsubscribed or not subscription.is_active:
-            logger.info('Subsciption updates profile rev')
+            user = subscription.profile.user
 
-            subscription.profile.update_rev(True)
+            if not getattr(user, '__dssoa__creating', False):
+                logger.info('Subsciption updates profile rev for "{}"'.format(user))
+
+                subscription.profile.update_rev(True)
