@@ -1,13 +1,8 @@
-import logging
-
 from django.contrib.auth import get_user_model, forms
 from django.core.exceptions import ValidationError
 from django.utils.translation import ugettext_lazy as _
 
-from ... import app_settings
-
 User = get_user_model()
-logger = logging.getLogger('django_sso_app.core.apps.users')
 
 
 class UserChangeForm(forms.UserChangeForm):
@@ -16,6 +11,7 @@ class UserChangeForm(forms.UserChangeForm):
 
 
 class UserCreationForm(forms.UserCreationForm):
+
     error_message = forms.UserCreationForm.error_messages.update(
         {"duplicate_username": _("This username has already been taken.")}
     )
@@ -37,11 +33,10 @@ class UserCreationForm(forms.UserCreationForm):
     def __init__(self, *args, **kwargs):
         super(UserCreationForm, self).__init__(*args, **kwargs)
 
-        if app_settings.BACKEND_ENABLED:
-            # removing unnecessary password fields
-            self.fields['password1'].required = False
-            self.fields['password2'].required = False
-            # If one field gets autocompleted but not the other, our 'neither
-            # password or both password' validation will be triggered.
-            self.fields['password1'].widget.attrs['autocomplete'] = 'off'
-            self.fields['password2'].widget.attrs['autocomplete'] = 'off'
+        # removing unnecessary password fields
+        self.fields['password1'].required = False
+        self.fields['password2'].required = False
+        # If one field gets autocompleted but not the other, our 'neither
+        # password or both password' validation will be triggered.
+        self.fields['password1'].widget.attrs['autocomplete'] = 'off'
+        self.fields['password2'].widget.attrs['autocomplete'] = 'off'
