@@ -31,7 +31,7 @@ from .serializers import (CheckUserExistenceSerializer,
 from ...apps.emails.models import EmailAddress
 from ...permissions import StaffPermission
 from ...permissions import is_staff, is_django_staff
-from ...utils import is_test_user, invalidate_cookie, get_session_key
+from ...utils import invalidate_cookie, get_session_key
 from ... import app_settings
 from .filters import UserFilter
 
@@ -188,32 +188,6 @@ class UserApiViewSet(mixins.ListModelMixin,
 
         return response
 
-    def delete_test_user(self, request, sso_id, *args, **kwargs):
-        logger.info('Deleting user')
-        requesting_user = self.request.user
-        logger.info('User "{}" wants to delete user with sso_id "{}"'.format(requesting_user, sso_id))
-
-        try:
-            user = self.get_object()
-            user_is_test_user = False
-
-            if is_test_user(user):
-                user_is_test_user = True
-                logger.info('deleting user "{}"'.format(user))
-                user.delete()
-
-        except Exception as e:
-            response = Response(_('Error deleting user "{}": {}').format(sso_id, e),
-                                status=status.HTTP_500_INTERNAL_SERVER_ERROR)
-
-        else:
-            response = Response(None, status=status.HTTP_200_OK)
-
-            if user_is_test_user:
-                invalidate_cookie(response, app_settings.JWT_COOKIE_NAME)
-
-        return response
-
 
 class UserRevisionsApiView(mixins.ListModelMixin,
                            viewsets.GenericViewSet):
