@@ -6,9 +6,13 @@ def is_authenticated(user):
     return user is not None and user.is_authenticated
 
 
+def is_django_staff(user):
+    return user and (user.is_staff or user.is_superuser)
+
+
 def is_staff(user):
     if user is not None:
-        if user.is_staff:
+        if is_django_staff(user):
             return True
 
         profile = getattr(user, 'sso_app_profile', None)
@@ -36,11 +40,11 @@ class StaffPermission(permissions.IsAuthenticated):
         return False
 
 
-class NotAdminUserPermission(permissions.IsAuthenticated):
-    message = 'Admin users are disabled.'
+class NotDjangoStaffUserPermission(permissions.IsAuthenticated):
+    message = 'Django staff users are disabled.'
 
     def has_permission(self, request, view):
-        if request.user.is_superuser:
+        if is_django_staff(request.user):
             return False
         return True
 
