@@ -10,11 +10,13 @@ from django.contrib.auth import logout as django_logout
 from rest_framework import status
 
 from allauth.account import views as allauth_account_views
+from allauth.account.adapter import get_adapter
 from allauth.socialaccount import views as allauth_socialaccount_views
 
 from .permissions import is_django_staff, is_authenticated
-from .utils import set_cookie, invalidate_cookie, set_session_key, get_session_key, get_random_fingerprint
+from .utils import set_cookie, invalidate_cookie, set_session_key, get_session_key, get_random_fingerprint, check_user_can_login
 from .mixins import WebpackBuiltTemplateViewMixin
+from .exceptions import ProfileIncompleteException
 from . import app_settings
 
 logger = logging.getLogger('django_sso_app.core')
@@ -55,8 +57,8 @@ class LoginView(allauth_account_views.LoginView, DjangoSsoAppBaseViewMixin, Webp
     def get(self, request, *args, **kwargs):
         logger.info('Getting login')
 
-        if is_authenticated(request.user):
-            return redirect(reverse('profile'))
+        #if is_authenticated(request.user):
+        #    return redirect(reverse('profile'))
 
         try:
             return super(LoginView, self).get(request, *args, **kwargs)
@@ -76,6 +78,13 @@ class LoginView(allauth_account_views.LoginView, DjangoSsoAppBaseViewMixin, Webp
 
             response = super(LoginView, self).post(request, *args, **kwargs)
 
+            location = response.get('location', None)
+            if location == reverse('account_email_verification_sent'):
+                logger.info('User "must confirm email"'.format(request.user))
+
+                adapter = get_adapter(self.request)
+                adapter.logout(request)
+
         except:
             logger.exception('Error logging in')
             raise
@@ -148,7 +157,7 @@ class SignupView(allauth_account_views.SignupView, DjangoSsoAppBaseViewMixin, We
 
         else:
             # log signup failed
-            if response.status_code != '302':
+            if response.status_code not in [200, 302]:
                 if hasattr(response, 'render'):
                     response.render()
                 logger.warning('User failed to register: "{}"'.format(response.content))
@@ -160,27 +169,39 @@ class SignupView(allauth_account_views.SignupView, DjangoSsoAppBaseViewMixin, We
         return response
 
 
-class ConfirmEmailView(allauth_account_views.ConfirmEmailView):
+class ConfirmEmailView(allauth_account_views.ConfirmEmailView, DjangoSsoAppBaseViewMixin):
     def get(self, request, *args, **kwargs):
         logger.info('Getting confirm email')
 
         try:
-            return super(ConfirmEmailView, self).get(request, *args, **kwargs)
+            response = super(ConfirmEmailView, self).get(request, *args, **kwargs)
 
         except:
             logger.exception('Error get confirm email')
             raise
 
+        else:
+            if is_authenticated(request.user):
+                response = self.get_response_with_cookie(request, response)
+
+            return response
+
     def post(self, request, *args, **kwargs):
         logger.info('Confirming email')
 
         try:
-            return super(ConfirmEmailView, self).post(request, *args, **kwargs)
+            response = super(ConfirmEmailView, self).post(request, *args, **kwargs)
 
         except:
             logger.exception('Error confirming email')
             raise
 
+        else:
+            if is_authenticated(request.user):
+                response = self.get_response_with_cookie(request, response)
+
+            return response
+
 
 class EmailView(allauth_account_views.EmailView):
     def get(self, *args, **kwargs):
@@ -228,7 +249,7 @@ class PasswordChangeView(allauth_account_views.PasswordChangeView):
             raise
 
 
-class PasswordSetView(allauth_account_views.PasswordSetView):
+class PasswordSetView(allauth_account_views.PasswordSetView, DjangoSsoAppBaseViewMixin):
     def get(self, *args, **kwargs):
         logger.info('Getting password set')
 
@@ -239,16 +260,22 @@ class PasswordSetView(allauth_account_views.PasswordSetView):
             logger.exception('Error getting password set')
             raise
 
-    def post(self, *args, **kwargs):
+    def post(self, request, *args, **kwargs):
         logger.info('Setting password')
 
         try:
-            return super(PasswordSetView, self).post(*args, **kwargs)
+            response = super(PasswordSetView, self).post(request, *args, **kwargs)
 
         except:
             logger.exception('Error setting password')
             raise
 
+        else:
+            adapter = get_adapter(request)
+            adapter.try_update_response_jwt(request.user, response)
+
+            return response
+
 
 class PasswordResetView(allauth_account_views.PasswordResetView, DjangoSsoAppBaseViewMixin, WebpackBuiltTemplateViewMixin):
     def get(self, *args, **kwargs):
